==> nextcloud-27.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_reminders/l10n/hu.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Fájl emlékeztetők",
    "Reminder for {name}" : "Emlékeztető a következőhöz: {name}",
    "View file" : "Fájl megtekintése",
    "View folder" : "Mappa megtekintése",
    "Set file reminders" : "Fájl emlékeztetők beállítása",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Fájl emlékeztetők**\n\nFájl emlékeztetők beállítása.",
    "Back" : "Vissza",
    "Clear reminder" : "Emlékeztető törlése",
    "Set custom reminder" : "Egyéni emlékeztető beállítása",
    "Later today" : "Mai nap később",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Tomorrow" : "Holnap",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "This weekend" : "Ezen a héten",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Next week" : "Következő hét",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
    "Set reminder at custom date & time" : "Emlékeztető beállítása tetszőleges időpontra",
    "Reminder set for \"{fileName}\"" : "Emlékeztető beállítva a következőhöz: {name}",
    "Failed to set reminder" : "Nem sikerült beállítani az emlékeztetőt",
    "Please choose a valid date & time" : "Adjon meg egy érvényes dátumot és időt",
    "Reminder cleared" : "Emlékeztető törölve",
    "Failed to clear reminder" : "Nem sikerült törölni az emlékeztetőt",
    "Failed to load reminder" : "Nem sikerült betölteni az emlékeztetőt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_reminders/l10n/hu.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Fájl emlékeztetők",
    "Reminder for {name}" : "Emlékeztető a következőhöz: {name}",
    "View file" : "Fájl megtekintése",
    "View folder" : "Mappa megtekintése",
    "Set file reminders" : "Fájl emlékeztetők beállítása",
    "Set reminder for \"{fileName}\"" : "Emlékeztető beállítása a következőhöz: „{fileName}”",
    "Set reminder at custom date & time" : "Emlékeztető beállítása tetszőleges időpontra",
    "Clear reminder" : "Emlékeztető törlése",
    "Please choose a valid date & time" : "Adjon meg egy érvényes dátumot és időt",
    "Reminder set for \"{fileName}\"" : "Emlékeztető beállítva a következőhöz: {fileName}",
    "Failed to set reminder" : "Nem sikerült beállítani az emlékeztetőt",
    "Reminder cleared for \"{fileName}\"" : "Emlékeztető törlése a következőhöz: „{fileName}”",
    "Failed to clear reminder" : "Nem sikerült törölni az emlékeztetőt",
    "We will remind you of this file" : "Emlékeztetni fogjuk Önt erre a fájlra",
    "Cancel" : "Mégse",
    "Set reminder" : "Emlékeztető beállítása",
    "Reminder set" : "Emlékeztető beállítása",
    "Set custom reminder" : "Egyéni emlékeztető beállítása",
    "Later today" : "Mai nap később",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Tomorrow" : "Holnap",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "This weekend" : "Ezen a héten",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Next week" : "Következő hét",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre"
},
"nplurals=2; plural=(n != 1);");
